%Function that calculates probabilities of non labelled part of the molecule having 0,1,...,n extra neutrons
%elementsOfMolecule = non labelled atom types of the molecule
%elementCounts = the amount of different kind of non labelled atoms in molecule
%maxSumOfLabels = maximum amount extra neutrons in the compound

function y = CalculateNatIsotopDistr(elementsOfMolecule,elementCounts, maxSumOfLabels)

  %calculate multinomials for each atom
  
  global elements;
  
  
  if length(elementsOfMolecule) ~= length(elementCounts)
      myError ('Sizes of parametervectors do not match!','Error in CalculateNatisotopDistr');     
  end
  
  atomTypeCount = length(elementsOfMolecule);
  multinomialMatrix = zeros(0,atomTypeCount);
  labelProbabilities = zeros(1,maxSumOfLabels + 1);
  amountOfIsotopes = zeros(1,atomTypeCount);
  
  % calculate probabilies of different amounts of labels in each atomtype using multinomials of natural abundances 
  for i = 1:atomTypeCount
      j = 1;
      notFound = 1;
      tempCol = zeros(0,1);
      
      %find abundance matrix of current atom
      while notFound == 1
          if strcmp(elements(j).name,elementsOfMolecule(i))
              notFound = 0;
              isotopes = elements(j).isotopes;
              amountOfIsotopes(i) = length(elements(j).isotopes);
          else
              j = j + 1;
              if j > length(elements) %abundance matrix was not found!
                  myError('Atomtype was not found from elements-table!','Error in CalculateMassIsopDistr');
              end
          end
      end
      
      tempMult = CalculateMultProb(isotopes, elementCounts(i), 0);
      tempCol = cat(1,tempCol,tempMult);
      j = 1;
               
      
      while tempMult > 0 & (length(isotopes) -1) * elementCounts(i) >= j  % if probability > 0 and it is possible to get j labels
        tempMult = CalculateMultProb(isotopes, elementCounts(i), j);
        if tempMult > 0
            tempCol = cat(1,tempCol,tempMult);
            j = j + 1;
        end
      end
      
      
      
      %make sure that tempCol and multinomialMatrix can be concatenated
      if size(tempCol,1) < size(multinomialMatrix,1) 
          temp = zeros (size(multinomialMatrix,1) - size(tempCol,1),1);
          tempCol = cat (1,tempCol, temp);
      else
      
         if size(tempCol,1) > size(multinomialMatrix,1)
             temp = zeros(size(tempCol,1) - size(multinomialMatrix,1),atomTypeCount);
             multinomialMatrix = cat (1,multinomialMatrix, temp);
         end
     end     
     multinomialMatrix(:,i) = tempCol;        
 end
 
 %calculate probabilities of different amounts of labels in the rest of the molecule, Can this be done more efficiently???
 
 for i = 0 : maxSumOfLabels % for each label combination in compound
 
   combCand = zeros(1,atomTypeCount);
   labelCombinations = zeros(0,atomTypeCount);
   labelCombinations = CreateAtomCombMatrix(elementCounts.*(amountOfIsotopes-1),i,combCand,1,labelCombinations);
   for j = 1: size(labelCombinations,1) % for each row labelCombination-matrix
       temp = 1;
       for k = 1 : atomTypeCount % for each column in labelCombination-matrix
           temp = temp * multinomialMatrix(labelCombinations(j,k)+1,k); % +1 because zero labels is stored to 1st row
       end
       
       labelProbabilities(i + 1) =  labelProbabilities(i + 1) + temp;
   end
end
 
labelProbabilities = labelProbabilities / sum (labelProbabilities);
y = labelProbabilities;
 
          
 

