%function that parses the line of the input file
%textLine = line to be parsed
%isInspect = whether positional isotopomer distribution is to be computed or ranks of possible fragmentation schemes is inspected
function y = Parse(textLine,isInspect)

    global labelType;

    [mzStr, reminder] = strtok (textLine);
    result.mz = str2num(mzStr); 
    if isempty(result.mz)
        myError('Malformed input file!', 'Error in Parse');
    end
    
    if ~isInspect  % we are calculating isotopomer distribution, not inspecting rank
    
        [intensityStr, reminder] = strtok(reminder);
        result.int = str2num(intensityStr);
        if isempty(result.int)
            error('Malformed input file!');
        end
    end
    
    [formulaStr, reminder] = strtok(reminder);
    i = 1;
    endPos = length(formulaStr);%errorhandling!!!
    formulaStr = upper(formulaStr);
    result.formulaString = formulaStr;
    if isempty(result.formulaString)
         myError('Malformed input file!', 'Error in Parse');
    end  
    
    if ~isletter(formulaStr(i))
        myError('Malformed atom formula in input file','error in parse');
    end
    
    %parse atom formula
    
    
    atomCounter = 1;

    
    while i <= endPos
        if (i + 1 <= endPos & ~isletter(formulaStr(i+1)) & ~isspace(formulaStr(i+1))) | i == endPos % next char is number or current char is last one
            isFound = isElement(formulaStr(i));
            if isFound == 0
                myError('Unknown atomtype in input file','Error in parse');
            else
                result.formula(atomCounter) = {formulaStr(i)};
            end
            
        else
            if isletter(formulaStr(i+1)) 
                temp(1) = formulaStr(i);
                temp(2) = formulaStr(i + 1);
                isFound = isElement(temp);
                if isFound ~= 0
                    i = i + 1;
                    result.formula(atomCounter) = {temp};
                else
                  isFound = isElement(formulaStr(i));
                  if isFound == 0
                      myError('Unknown atomtype in input file','Error in parse');
                  else
                      result.formula(atomCounter) = {formulaStr(i)};
                  end
                  
                end
            end
        end
        
        
        n = 1;
        if i + 1 <= endPos
            if isletter(formulaStr(i+1))
                result.atomCount(atomCounter) = 1;
            else
                k = i + 1; 
                tempStr = '';
                while k <= endPos & ~isletter(formulaStr(k))  % short circuited AND
                    tempStr(n) = formulaStr(k);
                    k = k + 1;
                    n = n + 1;
               end 
               result.atomCount(atomCounter) = str2num(tempStr); 
            end
        else
            result.atomCount(atomCounter) = 1;% current char is the last one in the string
        end
        atomCounter = atomCounter + 1;
        i = i + n;
        
    end %while
    
    
    % parse carbon locations. Just remove 'C's now. Actual mapping is done later
    
    carbonCounter = 1;
    [CarbonStr, reminder] = strtok(reminder);
    i = 1;
    endPos = length(CarbonStr);
    if endPos < 2
        myError('Malformed carbonstring in input file!','Error in parse');
    end
    
    while i + 1 <= endPos
        if ~(upper(CarbonStr(i)) == labelType)
            myError('Malformed carbonstring in input file!','Error in parse');
        end
        k = i + 1;
        n = 1;
        tempStr = '';
        while k <= endPos & ~(upper(CarbonStr(k)) == labelType)  % short circuited AND
                    tempStr(n) = CarbonStr(k);
                    k = k + 1;
                    n = n + 1;
        end
        result.carbons(carbonCounter) = {tempStr};
        carbonCounter = carbonCounter + 1;
        i = i + n;
    end
    
   
    % check if the original peak is spesified
    result.peak = str2num(reminder); 
    
    if  isempty(result.peak)  
          result.peak = -1;
    end
    
    y = result;
   

       
        
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    