%Function that reads the input file
%filename = name of the input file
%isInspect = whether user wants to compute the positional isotopomer distribution or inspect the rank resulting linear equation system
function y = ReadFile(filename, isInspect)

    %filename = 'data.txt';
    global carbonMapping;
    global labelType;
    %global isDaughterScan;
    
    k =  1;
    i = 1;
    fid = fopen(filename);
    wholeMolecule = 2;
    
    if fid == -1
        myError ('Cannot open file','Error in ReadFile');
    end
    
    
    while 1
          tline = fgetl(fid);
          if sum(~isspace(tline))== 0 | length(tline) == 0 | tline == -1, break, end
          if isletter(tline) 
              i = i + 1;
              continue;
          end
          try
              lines(i) = {Parse(tline,isInspect)}; %parse string and store components to lines
          catch
              fclose(fid);
              myError(lasterr,'Error in input file');
          end
          
          
          
          
         %is this line from same fragment as last one?
         if i > 1 & isSameFragment(lines{i}, lines{i - 1})
               addMass = lines{i}.mz - baseMass;
               fragments{k}.intensities(addMass + 1) = lines{i}.int;
         else % beginning of the new fragment
                    k = k + 1;
                    baseMass = CalculateBaseMass(lines{i}.formula, lines{i}.atomCount);
                    addMass = lines{i}.mz - baseMass;
                    if addMass < 0
                        myError ('Mass of fragment is smaller than base mass','Error in input file');
                    end
                    fragments{k}.mz = baseMass;
                    fragments{k}.peak = lines{i}.peak;
                    %if fragments{k}.peak > -1
                     %   isDaughterScan = 1;
                     %end
                    fragments{k}.carbons = lines{i}.carbons;
                    fragments{k}.formula = lines{i}.formula;
                    fragments{k}.formulaString = lines{i}.formulaString;
                    fragments{k}.atomCount = lines{i}.atomCount;
                    if ~isInspect 
                        fragments{k}.intensities(addMass + 1) = lines{i}.int;
                    end
                    if fragments{k}.mz > fragments{wholeMolecule}.mz
                        wholeMolecule = k;
                    end
          end
            
         i = i + 1;      
    end
    fclose(fid);
    
    % move whole molecule to the head of fragments
    
    fragments{1}= fragments{wholeMolecule};
    fragments(wholeMolecule) = [];
    
    carbonMapping = fragments{1}.carbons;
    
    %remove impossible peaks. this could have been done simultaneously with assigments above too...
    %i = 2;
    %while 1 
    %    if i > length(fragments)
    %        break;
    %    end
    %    if (fragments{i}.peak > -1)
    %        if (length(fragments{i}.intensities) > fragments{i}.peak + 1) %vrin!!!
    %            fragments{i}.intensities = fragments{i}.intensities(1:fragments{i}.peak + 1);
    %            if sum (fragments{i}.intensities)== 0 % nothing left in the fragment, remove
    %                fragments(i)= [];
    %                i = i - 1;
    %            end
    %        end
    %    end  
    %    i = i + 1;
    %end
    
    %convert fragment.carbons to bitvector
    i = 2;
    while i <= length(fragments);
        tempVect = zeros(1,length(fragments{1}.carbons));
        for j = 1 : length(fragments{i}.carbons)
            pos = FindCarbonPos(fragments{i}.carbons{j}, fragments{1}.carbons);
            if pos == -1
                myError('Unknown carbon position!','Error in ReadFile');
            end
            tempVect(pos) = 1;
        end
        fragments{i}.carbons = [];
        fragments{i}.carbons = tempVect;
        i = i + 1;
    end
    fragments{1}.carbons = ones(1,length(fragments{1}.carbons));
    
    %check that the amount of carbons is the same in fragments.carbons and in fragments.atomCount 
   
    for i = 1 : length(fragments)
        temp = 0;
        for j = 1 : length(fragments{i}.formula)
            if fragments{i}.formula{j} == labelType
                temp = j;
                break;
            end
        end
        if temp == 0
            myError('Labeled atomtype not present in molecule','Error in input file');
        else
            if fragments{i}.atomCount(temp) ~= length(find(fragments{i}.carbons))
                myError('Contradiction in the amounts of carbons','Error in input file');
            end
        end
    end
        
    y = fragments;
    
    
            
            
    
    
    
    