%function that writes the output files containng mass and positional isotopomer distributions
%posIsotDistr = positional isotopomer distribution
%filename = beginning of the names of the output files
function y = WriteFiles(posIsotDistr, filename)

    global fragments;
    global combinatorialMatrix;
    global carbonMapping;
    global isLastUnderDetermined;
    global peakWarning;
    global epsilon;
    
    %write Positional isotopomer distribution
    
    posFileName = strcat(filename,'_positional.txt');
    
    fid = fopen(posFileName,'w');
    
    if fid == -1
        myError ('Could not open file!','Error in WriteFile');
        return;
    end
    
    fprintf(fid,'%s\n',date);
    %if isLastUnderDetermined == 1
        %fprintf(fid,'Warning: Linear system used to solve positional isotopomers was underdetermined!\n\n');
     
        %end
        
    if ~isempty(peakWarning)
        fprintf(fid,'Warning: %s\n\n',peakWarning);
    end
        
    fprintf(fid,'%s:\n',fragments{1}.formulaString);
    tempStr = '';
    temp4 = '';
    for i = 1 : size(posIsotDistr,1)
      if posIsotDistr(i,size(posIsotDistr,2))~= 0 
        temp = find (posIsotDistr(i,:)> epsilon | -epsilon > posIsotDistr(i,:)); %don't print really small isotopomer fractions
        for j = 1 : length (temp)
            if temp(j) ~= size(posIsotDistr,2)
                temp2 = transpose(combinatorialMatrix(:,temp(j)));
                temp3 = mat2str(temp2);
                %if posIsotDistr(i,temp(j)) == -1
                if (posIsotDistr(i,temp(j)) < -1 + epsilon & posIsotDistr(i,temp(j)) > -1 - epsilon) 
                  temp4 = '-';
                else
                    if posIsotDistr(i,temp(j)) < 0
                        temp4 = mat2str(posIsotDistr(i,temp(j)));
                        temp4 = strcat(temp4,'*');
                    else
                  
                        if j > 1
                            temp4 = '+';
                        end
                        if (posIsotDistr(i,temp(j)) < 1 - epsilon | posIsotDistr(i,temp(j)) > 1 + epsilon) 
                            temp4 = strcat(temp4, mat2str(posIsotDistr(i,temp(j))));
                            temp4 = strcat(temp4,'*');
                        end
                    end
                end
                temp3 = strcat(temp4,temp3);     
                tempStr = strcat(tempStr,temp3,' ');
                temp4 = '';
            end
        end
      
        fprintf(fid,'%s\t',tempStr);
        fprintf(fid, '%10.8f\n',posIsotDistr(i,size(posIsotDistr,2)));
        tempStr = '';
      end     
    end
       
    %%for i = 1 : size(combinatorialMatrix,2)
    %%    temp = transpose (combinatorialMatrix(:,i));
    %%    tempStr = mat2str(temp);
    %%    fprintf(fid,'%s\t',tempStr);
    %%    fprintf(fid, '%6.5f\n',posIsotDistr(i));
    %%end
        
    fprintf(fid,'\n\n\n');
    
    fprintf(fid,'Order of labels: %s',char(carbonMapping));
    fclose(fid);
    
    %write mass isotopomer distribution
    
    posFileName = strcat(filename,'_mass.txt');
    
    fid = fopen(posFileName,'w');
    
    if fid == -1
        myError ('Could not open file!','Error in WriteFile');
    end
    
    
    
    for i = 1 : length(fragments)
        if fragments{i}.peak > -1
            tempStr = num2str(fragments{i}.peak);
        else
            tempStr = 'orig. molecule';
        end
        fprintf(fid,'%s(%s):\n',fragments{i}.formulaString,tempStr);
        tempVect = zeros(1,length(fragments{i}.intensities));
        for j = 0 : length(tempVect) -1
            tempVect(j+1) = j;
        end
        if fragments{i}.peak > -1
            tempVect2 = fragments{i}.intensities / fragments{1}.intensities(fragments{i}.peak + 1); 
        else
            tempVect2 = fragments{i}.intensities;
        end
        %%tempVect = cat(1,tempVect,transpose(fragments{i}.intensities));
        tempVect = cat(1,tempVect,transpose(tempVect2));
        fprintf(fid,'%d\t%9.5f\n',tempVect);
        fprintf(fid,'\n\n');
    end
    fclose(fid);
    
    y = 1;